<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 6335 $ -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name>: P&aacute;gina de informa&ccedil;&otilde;es</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Informa&ccedil;&atilde;o sobre <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> Para ver as mensagens anteriormente enviadas para a lista,
	      visite os <MM-Archive> Arquivos de <MM-List-Name>
		  </MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Utilizar <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Para enviar uma mensagem para todos os membros da lista, 
	    envie um email para
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Pode inscrever-se na lista ou mudar a sua incri&ccedil;&atilde;o 
	      nas sec&ccedil;&otilde;es abaixo.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Inscrever-se em <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    Inscreva-se em <MM-List-Name> preenchendo o seguinte formul&aacute;rio.
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">O seu endere&ccedil;o de email:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">O seu nome (opcional):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>Pode escolher uma password.
	    Ela d&aacute;-lhe uma seguran&ccedil;a m&eacute;dia, mas deve bastar para evitar 
            que outros interfiram com a sua participa&ccedil;&atilde;o. 
	    <b>N&atilde;o utilize uma password importante</b> visto que ela
            lhe ser&aacute; enviada ocasionalmente, via email, em texto n&atilde;o
            encriptado.

            <br><br>Se n&atilde;o escolher uma password, o sistema gerar&aacute; uma para si.
            Ela ser&aacute; enviada logo que confirme a sua inscri&ccedil;&atilde;o. Pode sempre
            pedir para receber a password por email quando editar as suas
            op&ccedil;&otilde;es pessoais.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">Escolher uma password:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">Reintroduzir a password para confirmar:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">Em que l&iacute;ngua prefere ver as suas mensagens?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>Prefere receber as suas mensagens agrupadas (digested) diariamente?
	  </td>
	<td><MM-Undigest-Radio-Button> N&atilde;o
	    <MM-Digest-Radio-Button>  Sim
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000"><MM-List-Name>: Lista de participantes</FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
