<!-- $Revision: 3550 $ -->
<html>
<head><title><MM-List-Name> نتایج اشتراک </title></head>
<body bgcolor="white" dir="rtl">
<h1><MM-List-Name>  نتایج اشتراک </h1>
<MM-Results>
<MM-Mailman-Footer>
</body>
</html>
